/*
	
	SolitaireWindow.cpp
	
	by Chris Page
	
*/

#ifndef _APPLICATION_H
#include <Application.h>
#endif

#ifndef _ALERT_H
#include <Alert.h>
#endif

#ifndef SOLITAIRE_MODEL_H
#include "SolitaireModel.h"
#endif

#ifndef SOLITAIRE_VIEW_H
#include "SolitaireView.h"
#endif

#ifndef SOLITAIRE_WINDOW_H
#include "SolitaireWindow.h"
#endif


SolitaireWindow::SolitaireWindow(BRect frame)
				: BWindow(frame, "Solitaire", B_TITLED_WINDOW,
							B_NOT_H_RESIZABLE + B_NOT_ZOOMABLE)
{
	DB_TRACE("SolitaireWindow::SolitaireWindow");
	
	// Disable this during development.
//	this->SetDiscipline(FALSE);
	
	// Create the game model.
	this->solitaire = new SolitaireModel();
	
	// Create a new game view that covers the entire window content.
	BRect viewRect(Bounds());
	viewRect.right++;
	viewRect.bottom++;
	SolitaireView *view = new SolitaireView(viewRect, this->solitaire);
	AddChild(view);
}


// Delete the game model.

SolitaireWindow::~SolitaireWindow()
{
	DB_TRACE("SolitaireWindow::~SolitaireWindow");
	
	delete this->solitaire;
}


// Close the window. Ask for verification. This also provides for
// starting a new game.

bool SolitaireWindow::QuitRequested()
{
	DB_TRACE("SolitaireWindow::QuitRequested");
	
	char *message;
	if (this->solitaire->Won())
		message = "Are you sure you want to quit?";
	else
		message = "There is a game in progress. If you quit now,"
				  " you'll never know the Happy! Happy! Joy! Joy! of winning."
				  " Are you sure you want to quit?";
	
	BAlert *alert = new BAlert(NULL, message, "New Game", "Play", "Quit",
		B_WIDTH_AS_USUAL, B_WARNING_ALERT);
	alert->SetShortcut(1, B_ESCAPE);
	int result = alert->Go();
	
	if (result == 1 /* Play */)
		return FALSE;
	if (result == 0 /* New Game */)
	{
		// Delete the old game and create a new one.
		delete ChildAt(0);
		delete this->solitaire;
		
		// Create the game model.
		this->solitaire = new SolitaireModel();
		
		// Create a new game view that covers the entire window content.
		BRect viewRect(Bounds());
		viewRect.right++;
		viewRect.bottom++;
		SolitaireView *view = new SolitaireView(viewRect, this->solitaire);
		AddChild(view);
		
		return FALSE;
	}
	
	// Tell the application to quit, too.
	be_app->PostMessage(B_QUIT_REQUESTED);
	
	return TRUE;
}
