/*
	
	HandModel.cpp
	
	by Chris Page
	
*/

#ifndef CARD_MODEL_H
#include "CardModel.h"
#endif

#ifndef HAND_MODEL_H
#include "HandModel.h"
#endif


// Create an empty hand.

HandModel::HandModel()
{
	DB_TRACE("HandModel::HandModel");
	
	this->cards = new BList(cCardCount);
}


// Delete all the cards in the hand.

HandModel::~HandModel()
{
	DB_TRACE("HandModel::~HandModel");
	
	while (!this->cards->IsEmpty())
		delete (CardModel*) this->cards->RemoveItem(0L);
	delete this->cards;
}


// Deal a card to the top of the hand.

void HandModel::Add(CardModel *card)
{
	DB_TRACE("HandModel::Add");
	
	this->cards->AddItem(card);
}


// Remove the top card from the hand. If the hand is empty,
// NULL is returned.

CardModel *HandModel::Remove()
{
	DB_TRACE("HandModel::Remove");
	
	return (CardModel*)
		this->cards->RemoveItem(this->cards->CountItems() - 1);
}


// Remove the bottom card from the hand. If the hand is empty,
// NULL is returned.

CardModel *HandModel::RemoveBottom()
{
	DB_TRACE("HandModel::RemoveBottom");
	
	return (CardModel*) this->cards->RemoveItem(0L);
}


// Return the top card of the hand. This does not remove the card.

CardModel *HandModel::Top() const
{
	DB_TRACE("HandModel::Top");
	
	return (CardModel*) this->cards->LastItem();
}


// Return the specified card. This does not remove the card.

CardModel *HandModel::CardAt(long index) const
{
	DB_TRACE("HandModel::CardAt");
	
	return (CardModel*) this->cards->ItemAt(index);
}


// Return TRUE if the hand is empty.

bool HandModel::IsEmpty() const
{
	DB_TRACE("HandModel::IsEmpty");
	
	return this->cards->IsEmpty();
}


// Return the number of cards in the hand.

long HandModel::Count() const
{
	DB_TRACE("HandModel::Count");
	
	return this->cards->CountItems();
}
